@@ -7,13 +7,14 @@ from .exc import InvalidTermError
 
 class Memo(object):
     """ A lightweight, picklable container for document data.  Contain
-    all the data elements necessary to construct a xapaian document."""
+    all the data elements necessary to construct a xapian document."""
 
     def __init__(self):
         self.lang = None
         self.terms = []    # (term, type) | (term, type, wdfinc)
         self.posts = []    # (term, position) | (term, position, wdfinc)
-        self.texts = []    # {text=u"", lang=None, stem=True, stop=True}
+        self.texts = []    # {text=u"", lang=None, stem=True, stop=True,
+                           #  posit=True, post_start=None}
         self.values = []   # (name, value, type)
         self.data = None   # bytestring or None
 
@@ -52,14 +53,17 @@ class Memo(object):
         self.posts.append(term)
 
     def add_text(self, text, prefix=None, lang=None,
-                 post=True, stem=True, stop=True, spell=True):
+                 post=True, stem=True, stop=True, spell=True,
+                 wdf_inc=None, post_start=None):
         self.texts.append(dict(text=text,
                                prefix=prefix,
                                lang=lang,
                                post=post,
                                stem=stem,
                                stop=stop,
-                               spell=True,
+                               spell=spell,
+                               wdf_inc=wdf_inc,
+                               post_start=post_start,
                                ))
 
     def add_value(self, name, value, type):
